package SSIS::Package::ConnectionManager::ADONET;

use 5.010;
use strict;
use warnings;

use parent qw/SSIS::Package::ConnectionManager/;

=head1 NAME

SSIS::Package::ConnectionManager::ADONET - SSIS ADONET package connection manager by Ded MedVed

=head1 VERSION

Version 0.02

=cut

our $VERSION = '0.02';


1 ;

__DATA__

1; # End of SSIS::Package::ConnectionManager::ADONET

